<?php

namespace Litecms\Faucet\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Faucet\Models\Faucet;

class FaucetPolicy
{

    /**
     * Determine if the given user can view the faucet.
     *
     * @param UserPolicy $user
     * @param Faucet $faucet
     *
     * @return bool
     */
    public function view(UserPolicy $user, Faucet $faucet)
    {
        if ($user->canDo('faucet.faucet.view') && $user->isAdmin()) {
            return true;
        }

        return $faucet->user_id == user_id() && $faucet->user_type == user_type();
    }

    /**
     * Determine if the given user can create a faucet.
     *
     * @param UserPolicy $user
     * @param Faucet $faucet
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('faucet.faucet.create');
    }

    /**
     * Determine if the given user can update the given faucet.
     *
     * @param UserPolicy $user
     * @param Faucet $faucet
     *
     * @return bool
     */
    public function update(UserPolicy $user, Faucet $faucet)
    {
        if ($user->canDo('faucet.faucet.update') && $user->isAdmin()) {
            return true;
        }

        return $faucet->user_id == user_id() && $faucet->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given faucet.
     *
     * @param UserPolicy $user
     * @param Faucet $faucet
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Faucet $faucet)
    {
        return $faucet->user_id == user_id() && $faucet->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given faucet.
     *
     * @param UserPolicy $user
     * @param Faucet $faucet
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Faucet $faucet)
    {
        if ($user->canDo('faucet.faucet.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given faucet.
     *
     * @param UserPolicy $user
     * @param Faucet $faucet
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Faucet $faucet)
    {
        if ($user->canDo('faucet.faucet.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
