<?php

namespace Litecms\Faucet\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Faucet\Models\Faucet;

class FaucetAction
{
    /**
     * Perform the complete action.
     *
     * @param Faucet $faucet
     *
     * @return Faucet
     */
    public function complete(Faucet $faucet)
    {
        try {
            $faucet->status = 'complete';
            return $faucet->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Faucet $faucet
     *
     * @return Faucet
     */public function verify(Faucet $faucet)
    {
        try {
            $faucet->status = 'verify';
            return $faucet->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Faucet $faucet
     *
     * @return Faucet
     */public function approve(Faucet $faucet)
    {
        try {
            $faucet->status = 'approve';
            return $faucet->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Faucet $faucet
     *
     * @return Faucet
     */public function publish(Faucet $faucet)
    {
        try {
            $faucet->status = 'publish';
            return $faucet->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Faucet $faucet
     *
     * @return Faucet
     */
    public function archive(Faucet $faucet)
    {
        try {
            $faucet->status = 'archive';
            return $faucet->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Faucet $faucet
     *
     * @return Faucet
     */
    public function unpublish(Faucet $faucet)
    {
        try {
            $faucet->status = 'unpublish';
            return $faucet->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
